@@ -3,7 +3,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ANDROID_API_LEVEL': 0,
- 'AR': 'aarch64-linux-gnu-gcc-ar',
+ 'AR': 'aarch64-linux-gnu-ar',
  'ARFLAGS': 'rcs',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '-IObjects -IInclude -IPython',
@@ -23,8 +23,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 -Wall -g '
            ' '
            ' -fstack-protector-strong '
-           '-Wformat -Werror=format-security  -g -flto -fuse-linker-plugin '
-           '-ffat-lto-objects',
+           '-Wformat -Werror=format-security',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -56,8 +55,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.6m',
  'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/build/python3.6-L3nKmF/python3.6-3.6.9/build-shared/coverage.info',
- 'COVERAGE_REPORT': '/build/python3.6-L3nKmF/python3.6-3.6.9/build-shared/lcov-report',
+ 'COVERAGE_INFO': '/build/python3.6-FX1Cgd/python3.6-3.6.8/build-shared/coverage.info',
+ 'COVERAGE_REPORT': '/build/python3.6-FX1Cgd/python3.6-3.6.8/build-shared/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Include -Wdate-time '
@@ -542,7 +541,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'aarch64-linux-gnu-gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
- 'MAJOR_IN_SYSMACROS': 0,
+ 'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': '../Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/bin/mkdir -p',
@@ -622,8 +621,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 -Wall '
               '-g  '
               ' -fstack-protector-strong '
-              '-Wformat -Werror=format-security  -g -flto -fuse-linker-plugin '
-              '-ffat-lto-objects',
+              '-Wformat -Werror=format-security',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Wno-cast-function-type',
@@ -631,9 +629,8 @@ build_time_vars = {'ABIFLAGS': 'm',
                    '-Wall -g '
                    ' '
                    ' '
-                   '-fstack-protector-strong -Wformat -Werror=format-security  -g '
-                   '-flto -fuse-linker-plugin -ffat-lto-objects -std=c99 '
-                   '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                   '-fstack-protector-strong -Wformat -Werror=format-security '
+                   '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wno-cast-function-type '
                    '-IObjects -IInclude -IPython -I. -I../Include -Wdate-time '
                    '-D_FORTIFY_SOURCE=2 -fPIC -DPy_BUILD_CORE',
@@ -649,7 +646,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.6-L3nKmF/python3.6-3.6.9/build-shared',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.6-FX1Cgd/python3.6-3.6.8/build-shared',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -690,10 +687,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.6-L3nKmF/python3.6-3.6.9/build-shared '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.6-FX1Cgd/python3.6-3.6.8/build-shared '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.6-L3nKmF/python3.6-3.6.9/build-shared '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.6-FX1Cgd/python3.6-3.6.8/build-shared '
                './python ../Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'THREADOBJ': 'Python/thread.o',
@@ -719,8 +716,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python3.6-L3nKmF/python3.6-3.6.9/build-shared',
- 'abs_srcdir': '/build/python3.6-L3nKmF/python3.6-3.6.9/build-shared/..',
+ 'abs_builddir': '/build/python3.6-FX1Cgd/python3.6-3.6.8/build-shared',
+ 'abs_srcdir': '/build/python3.6-FX1Cgd/python3.6-3.6.8/build-shared/..',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
